summaryrefslogtreecommitdiff
path: root/sw/source/core/draw
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 19:50:13 +0200
committerMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 20:03:50 +0200
commitee3189489c0205ec221fbc907a01c711b58fc42e (patch)
tree1cd2fd05e3518d9484b11f0fc29b6e458a629338 /sw/source/core/draw
parent2e99447fc07df98ebbc343ef79852b7eaf7b7757 (diff)
sw: ViewShell -> SwViewShell rename
It's a public class, so it should have the 'Sw' prefix. Change-Id: I0040c1cc37ffcba7fc5f58b71c86f4a7cb0bfce4
Diffstat (limited to 'sw/source/core/draw')
-rw-r--r--sw/source/core/draw/dcontact.cxx8
-rw-r--r--sw/source/core/draw/dflyobj.cxx6
-rw-r--r--sw/source/core/draw/dpage.cxx8
3 files changed, 11 insertions, 11 deletions
diff --git a/sw/source/core/draw/dflyobj.cxx b/sw/source/core/draw/dflyobj.cxx
index 6b83fea70c53..f25c61e5d31c 100644
--- a/sw/source/core/draw/dflyobj.cxx
+++ b/sw/source/core/draw/dflyobj.cxx
@@ -408,7 +408,7 @@ namespace
class RestoreMapMode
{
public:
- explicit RestoreMapMode( ViewShell* pViewShell )
+ explicit RestoreMapMode( SwViewShell* pViewShell )
: mbMapModeRestored( false )
, mpOutDev( pViewShell->GetOut() )
{
@@ -449,7 +449,7 @@ namespace
void SwVirtFlyDrawObj::wrap_DoPaintObject() const
{
- ViewShell* pShell = pFlyFrm->getRootFrm()->GetCurrShell();
+ SwViewShell* pShell = pFlyFrm->getRootFrm()->GetCurrShell();
// Only paint when we have a current shell and a DrawingLayer paint is in progress.
// This avcoids evtl. problems with renderers which do processing stuff,
@@ -780,7 +780,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef,
const SwFrm *pRel = GetFlyFrm()->IsFlyLayFrm() ?
GetFlyFrm()->GetAnchorFrm() :
GetFlyFrm()->GetAnchorFrm()->GetUpper();
- const ViewShell *pSh = GetFlyFrm()->getRootFrm()->GetCurrShell();
+ const SwViewShell *pSh = GetFlyFrm()->getRootFrm()->GetCurrShell();
if ( pSh && pRel->IsBodyFrm() &&
pSh->GetViewOptions()->getBrowseMode() &&
pSh->VisArea().HasArea() )
diff --git a/sw/source/core/draw/dpage.cxx b/sw/source/core/draw/dpage.cxx
index 5e73e87e7650..cb2daae2dfad 100644
--- a/sw/source/core/draw/dpage.cxx
+++ b/sw/source/core/draw/dpage.cxx
@@ -83,11 +83,11 @@ void InsertGridFrame( SdrPageGridFrameList *pLst, const SwFrm *pPg )
const SdrPageGridFrameList* SwDPage::GetGridFrameList(
const SdrPageView* pPV, const Rectangle *pRect ) const
{
- ViewShell *pSh = ((SwDrawDocument*)GetModel())->GetDoc().GetCurrentViewShell();
+ SwViewShell *pSh = ((SwDrawDocument*)GetModel())->GetDoc().GetCurrentViewShell();
if ( pSh )
{
while ( pSh->Imp()->GetPageView() != pPV )
- pSh = (ViewShell*)pSh->GetNext();
+ pSh = (SwViewShell*)pSh->GetNext();
if ( pSh )
{
if ( pGridLst )
@@ -182,9 +182,9 @@ sal_Bool SwDPage::RequestHelp( Window* pWindow, SdrView* pView,
bExecHyperlinks = !aSecOpts.IsOptionSet( SvtSecurityOptions::E_CTRLCLICK_HYPERLINK );
if ( !bExecHyperlinks )
- sTxt = ViewShell::GetShellRes()->aLinkCtrlClick + ": " + sTxt;
+ sTxt = SwViewShell::GetShellRes()->aLinkCtrlClick + ": " + sTxt;
else
- sTxt = ViewShell::GetShellRes()->aLinkClick + ": " + sTxt;
+ sTxt = SwViewShell::GetShellRes()->aLinkClick + ": " + sTxt;
}
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index cf5c1e9866b5..5c724dbaa539 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -1043,7 +1043,7 @@ void SwDrawContact::Changed( const SdrObject& rObj,
SdrUserCallType eType,
const Rectangle& rOldBoundRect )
{
// #i26791# - no event handling, if existing <ViewShell>
// is in contruction
SwDoc* pDoc = GetFmt()->GetDoc();
if ( pDoc->GetCurrentViewShell() &&
@@ -1061,7 +1061,7 @@ void SwDrawContact::Changed( const SdrObject& rObj,
}
//Put on Action, but not if presently anywhere an action runs.
- ViewShell *pSh = 0, *pOrg;
+ SwViewShell *pSh = 0, *pOrg;
SwRootFrm *pTmpRoot = pDoc->GetCurrentLayout();
if ( pTmpRoot && pTmpRoot->IsCallbackActionEnabled() )
{
@@ -1072,7 +1072,7 @@ void SwDrawContact::Changed( const SdrObject& rObj,
{ if ( pSh->Imp()->IsAction() || pSh->Imp()->IsIdleAction() )
pSh = 0;
else
- pSh = (ViewShell*)pSh->GetNext();
+ pSh = (SwViewShell*)pSh->GetNext();
} while ( pSh && pSh != pOrg );
@@ -1734,7 +1734,7 @@ void SwDrawContact::ConnectToLayout( const SwFmtAnchor* pAnch )
case FLY_AT_PAGE:
{
sal_uInt16 nPgNum = pAnch->GetPageNum();
- ViewShell *pShell = pDrawFrmFmt->getIDocumentLayoutAccess()->GetCurrentViewShell();
+ SwViewShell *pShell = pDrawFrmFmt->getIDocumentLayoutAccess()->GetCurrentViewShell();
if( !pShell )
break;
SwRootFrm* pRoot = pShell->GetLayout();
@@ -1043,7 +1043,7 @@ void SwDrawContact::Changed( const SdrObject& rObj,
const Rectangle& rOldBoundRect )
{
- // #i26791# - no event handling, if existing <ViewShell>
+ // #i26791# - no event handling, if existing <SwViewShell>
// is in contruction
SwDoc* pDoc = GetFmt()->GetDoc();